@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@ class AttributeKeyDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LabelType: 输入框类型
         :type LabelType: str
         :param Starter: 初始化展示
@@ -54,7 +54,7 @@ class AttributeKeyDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -64,7 +64,7 @@ class AuditSummary(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AuditStatus: 跟踪集状态，1：开启，0：关闭
         :type AuditStatus: int
         :param CosBucketName: COS存储桶名称
@@ -90,7 +90,7 @@ class AuditSummary(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -100,7 +100,7 @@ class CmqRegionInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CmqRegionName: 地域描述
         :type CmqRegionName: str
         :param CmqRegion: cmq地域
@@ -118,7 +118,7 @@ class CmqRegionInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -128,7 +128,7 @@ class CosRegionInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CosRegion: cos地域
         :type CosRegion: str
         :param CosRegionName: 地域描述
@@ -146,7 +146,7 @@ class CosRegionInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -156,7 +156,7 @@ class CreateAuditRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param IsEnableCmqNotify: 是否开启cmq消息通知。1：是，0：否。目前仅支持cmq的队列服务。如果开启cmq消息通知服务，云审计会将您的日志内容实时投递到您指定地域的指定队列中。
         :type IsEnableCmqNotify: int
         :param ReadWriteAttribute: 管理事件的读写属性。1：只读，2：只写，3：全部。
@@ -218,7 +218,7 @@ class CreateAuditRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -228,7 +228,7 @@ class CreateAuditResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param IsSuccess: 是否创建成功。
         :type IsSuccess: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -241,13 +241,6 @@ class CreateAuditResponse(AbstractModel):
     def _deserialize(self, params):
         self.IsSuccess = params.get("IsSuccess")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DeleteAuditRequest(AbstractModel):
@@ -256,7 +249,7 @@ class DeleteAuditRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AuditName: 跟踪集名称
         :type AuditName: str
         """
@@ -270,7 +263,7 @@ class DeleteAuditRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -280,7 +273,7 @@ class DeleteAuditResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param IsSuccess: 是否删除成功
         :type IsSuccess: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -293,13 +286,6 @@ class DeleteAuditResponse(AbstractModel):
     def _deserialize(self, params):
         self.IsSuccess = params.get("IsSuccess")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeAuditRequest(AbstractModel):
@@ -308,7 +294,7 @@ class DescribeAuditRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AuditName: 跟踪集名称
         :type AuditName: str
         """
@@ -322,7 +308,7 @@ class DescribeAuditRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -332,7 +318,7 @@ class DescribeAuditResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param IsEnableCmqNotify: 是否开启cmq消息通知。1：是，0：否。
         :type IsEnableCmqNotify: int
         :param ReadWriteAttribute: 管理事件读写属性，1：只读，2：只写，3：全部
@@ -393,13 +379,6 @@ class DescribeAuditResponse(AbstractModel):
         self.CmqRegion = params.get("CmqRegion")
         self.LogFilePrefix = params.get("LogFilePrefix")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeEventsRequest(AbstractModel):
@@ -408,7 +387,7 @@ class DescribeEventsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param StartTime: 起始时间戳（单位秒，不超过当前时间 90 天）
         :type StartTime: int
         :param EndTime: 结束时间戳（单位秒，查询时间跨度小于 30 天）
@@ -419,12 +398,15 @@ class DescribeEventsRequest(AbstractModel):
         :type MaxResults: int
         :param LookupAttributes: 检索条件（目前支持 RequestId：请求 ID、EventName：事件名称、ActionType：操作类型（Write：写；Read：读）、PrincipalId：子账号、ResourceType：资源类型、ResourceName：资源名称、AccessKeyId：密钥 ID、SensitiveAction：是否敏感操作、ApiErrorCode：API 错误码、CamErrorCode：CAM 错误码）
         :type LookupAttributes: list of LookupAttribute
+        :param IsReturnLocation: 是否返回 IP 归属地（1 返回，0 不返回）
+        :type IsReturnLocation: int
         """
         self.StartTime = None
         self.EndTime = None
         self.NextToken = None
         self.MaxResults = None
         self.LookupAttributes = None
+        self.IsReturnLocation = None
 
 
     def _deserialize(self, params):
@@ -438,12 +420,13 @@ class DescribeEventsRequest(AbstractModel):
                 obj = LookupAttribute()
                 obj._deserialize(item)
                 self.LookupAttributes.append(obj)
+        self.IsReturnLocation = params.get("IsReturnLocation")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -453,7 +436,7 @@ class DescribeEventsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ListOver: 日志集合是否结束
         :type ListOver: bool
         :param NextToken: 查看更多日志的凭证
@@ -480,13 +463,6 @@ class DescribeEventsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.Events.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class Event(AbstractModel):
@@ -495,7 +471,7 @@ class Event(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EventId: 日志ID
         :type EventId: str
         :param Username: 用户名
@@ -577,7 +553,7 @@ class Event(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -587,7 +563,7 @@ class GetAttributeKeyRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WebsiteType: 网站类型，取值范围是zh和en。如果不传值默认zh
         :type WebsiteType: str
         """
@@ -601,7 +577,7 @@ class GetAttributeKeyRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -611,7 +587,7 @@ class GetAttributeKeyResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AttributeKeyDetails: AttributeKey的有效取值范围
         :type AttributeKeyDetails: list of AttributeKeyDetail
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -629,13 +605,6 @@ class GetAttributeKeyResponse(AbstractModel):
                 obj._deserialize(item)
                 self.AttributeKeyDetails.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class InquireAuditCreditRequest(AbstractModel):
@@ -650,7 +619,7 @@ class InquireAuditCreditResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AuditAmount: 可创建跟踪集的数量
         :type AuditAmount: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -663,13 +632,6 @@ class InquireAuditCreditResponse(AbstractModel):
     def _deserialize(self, params):
         self.AuditAmount = params.get("AuditAmount")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class KeyMetadata(AbstractModel):
@@ -678,7 +640,7 @@ class KeyMetadata(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Alias: 作为密钥更容易辨识，更容易被人看懂的别名
         :type Alias: str
         :param KeyId: CMK的全局唯一标识
@@ -696,7 +658,7 @@ class KeyMetadata(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -712,7 +674,7 @@ class ListAuditsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AuditSummarys: 查询跟踪集概要集合
 注意：此字段可能返回 null，表示取不到有效值。
         :type AuditSummarys: list of AuditSummary
@@ -731,13 +693,6 @@ class ListAuditsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.AuditSummarys.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class ListCmqEnableRegionRequest(AbstractModel):
@@ -746,7 +701,7 @@ class ListCmqEnableRegionRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WebsiteType: 站点类型。zh表示中国区，en表示国际区。默认中国区。
         :type WebsiteType: str
         """
@@ -760,7 +715,7 @@ class ListCmqEnableRegionRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -770,7 +725,7 @@ class ListCmqEnableRegionResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EnableRegions: 云审计支持的cmq的可用区
         :type EnableRegions: list of CmqRegionInfo
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -788,13 +743,6 @@ class ListCmqEnableRegionResponse(AbstractModel):
                 obj._deserialize(item)
                 self.EnableRegions.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class ListCosEnableRegionRequest(AbstractModel):
@@ -803,7 +751,7 @@ class ListCosEnableRegionRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WebsiteType: 站点类型。zh表示中国区，en表示国际区。默认中国区。
         :type WebsiteType: str
         """
@@ -817,7 +765,7 @@ class ListCosEnableRegionRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -827,7 +775,7 @@ class ListCosEnableRegionResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EnableRegions: 云审计支持的cos可用区
         :type EnableRegions: list of CosRegionInfo
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -845,13 +793,6 @@ class ListCosEnableRegionResponse(AbstractModel):
                 obj._deserialize(item)
                 self.EnableRegions.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class ListKeyAliasByRegionRequest(AbstractModel):
@@ -860,7 +801,7 @@ class ListKeyAliasByRegionRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param KmsRegion: Kms地域
         :type KmsRegion: str
         :param Limit: 含义跟 SQL 查询的 Limit 一致，表示本次获最多获取 Limit 个元素。缺省值为10，最大值为200
@@ -882,7 +823,7 @@ class ListKeyAliasByRegionRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -892,7 +833,7 @@ class ListKeyAliasByRegionResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: CMK的总数量
         :type TotalCount: int
         :param KeyMetadatas: 密钥别名
@@ -914,13 +855,6 @@ class ListKeyAliasByRegionResponse(AbstractModel):
                 obj._deserialize(item)
                 self.KeyMetadatas.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class LookUpEventsRequest(AbstractModel):
@@ -929,7 +863,7 @@ class LookUpEventsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param StartTime: 开始时间
         :type StartTime: int
         :param EndTime: 结束时间
@@ -968,7 +902,7 @@ class LookUpEventsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -978,7 +912,7 @@ class LookUpEventsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param NextToken: 查看更多日志的凭证
 注意：此字段可能返回 null，表示取不到有效值。
         :type NextToken: str
@@ -1007,13 +941,6 @@ class LookUpEventsResponse(AbstractModel):
                 self.Events.append(obj)
         self.ListOver = params.get("ListOver")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class LookupAttribute(AbstractModel):
@@ -1022,7 +949,7 @@ class LookupAttribute(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AttributeKey: AttributeKey的有效取值范围是:RequestId、EventName、ReadOnly、Username、ResourceType、ResourceName和AccessKeyId，EventId
 注意：此字段可能返回 null，表示取不到有效值。
         :type AttributeKey: str
@@ -1042,7 +969,7 @@ class LookupAttribute(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1052,7 +979,7 @@ class Resource(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceType: 资源类型
         :type ResourceType: str
         :param ResourceName: 资源名称
@@ -1071,7 +998,7 @@ class Resource(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1081,7 +1008,7 @@ class StartLoggingRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AuditName: 跟踪集名称
         :type AuditName: str
         """
@@ -1095,7 +1022,7 @@ class StartLoggingRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1105,7 +1032,7 @@ class StartLoggingResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param IsSuccess: 是否开启成功
         :type IsSuccess: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1118,13 +1045,6 @@ class StartLoggingResponse(AbstractModel):
     def _deserialize(self, params):
         self.IsSuccess = params.get("IsSuccess")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class StopLoggingRequest(AbstractModel):
@@ -1133,7 +1053,7 @@ class StopLoggingRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AuditName: 跟踪集名称
         :type AuditName: str
         """
@@ -1147,7 +1067,7 @@ class StopLoggingRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1157,7 +1077,7 @@ class StopLoggingResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param IsSuccess: 是否关闭成功
         :type IsSuccess: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1170,13 +1090,6 @@ class StopLoggingResponse(AbstractModel):
     def _deserialize(self, params):
         self.IsSuccess = params.get("IsSuccess")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class UpdateAuditRequest(AbstractModel):
@@ -1185,7 +1098,7 @@ class UpdateAuditRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AuditName: 跟踪集名称
         :type AuditName: str
         :param IsEnableCmqNotify: 是否开启cmq消息通知。1：是，0：否。目前仅支持cmq的队列服务。如果开启cmq消息通知服务，云审计会将您的日志内容实时投递到您指定地域的指定队列中。
@@ -1247,7 +1160,7 @@ class UpdateAuditRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1257,7 +1170,7 @@ class UpdateAuditResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param IsSuccess: 是否更新成功
         :type IsSuccess: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1269,11 +1182,4 @@ class UpdateAuditResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.IsSuccess = params.get("IsSuccess")
-        self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
\ No newline at end of file
+        self.RequestId = params.get("RequestId")
\ No newline at end of file
