@@ -107,6 +107,9 @@ FAILEDOPERATION_PUBLISHLAYERVERSION = 'FailedOperation.PublishLayerVersion'
 # 当前函数状态无法发布版本，请在状态为正常时发布。
 FAILEDOPERATION_PUBLISHVERSION = 'FailedOperation.PublishVersion'
 
+# 角色不存在。
+FAILEDOPERATION_QCSROLENOTFOUND = 'FailedOperation.QcsRoleNotFound'
+
 # 当前函数已有保留并发设置任务处于进行中，请稍后重试。
 FAILEDOPERATION_RESERVEDINPROGRESS = 'FailedOperation.ReservedInProgress'
 
@@ -479,6 +482,9 @@ RESOURCEINUSE_CMQ = 'ResourceInUse.Cmq'
 # Cos已被占用。
 RESOURCEINUSE_COS = 'ResourceInUse.Cos'
 
+# 函数已存在。
+RESOURCEINUSE_FUNCTION = 'ResourceInUse.Function'
+
 # FunctionName已存在。
 RESOURCEINUSE_FUNCTIONNAME = 'ResourceInUse.FunctionName'
 
